package VMOMI::HostVmciAccessManagerMode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
